@@ -10,7 +10,7 @@ from metacatalog import models
 
 def _add(session, InstanceModel, **kwargs):
     """
-    Common method for inserting a new record. 
+    Common method for inserting a new record.
     Should not be used directly.
     """
     entity = InstanceModel(**kwargs)
@@ -28,7 +28,7 @@ def _add(session, InstanceModel, **kwargs):
 
 def add_record(session, tablename, **kwargs):
     """
-    Method to map tablenames to InstanceModels. 
+    Method to map tablenames to InstanceModels.
     Should not be used directly.
     """
     if not tablename in TABLE_MAPPING.keys():
@@ -40,31 +40,31 @@ def add_record(session, tablename, **kwargs):
 def add_license(session, short_title, title, **kwargs):
     """Add license record
 
-    Add a new License record to the database. 
+    Add a new License record to the database.
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     short_title : str
         Short title of the License, max 40 letters.
     title : str
         Full title of the License.
     summary : str
-        Gives a short summary of the key points for 
+        Gives a short summary of the key points for
         the given license.
     full_text : str
         Full legal code of the license, if available.
     link : str
         Link to an online resource of the license.
     by_attribution : bool
-        Does the license require author attribution on 
+        Does the license require author attribution on
         distribution? Defaults to True.
     share_alike : bool
-        Does the license require redistributions to be 
+        Does the license require redistributions to be
         licensed under the same license? Defaults to True.
     commercial_use : bool
-        Does the license permit commercial use of the 
+        Does the license permit commercial use of the
         resource? Defaults to True
 
     Return
@@ -91,17 +91,17 @@ def add_unit(session, name, symbol, si=None):
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     name : str
         The unit name. Max 64 letters.
     symbol : str
-        The unit symbol. Try to use the correct 
+        The unit symbol. Try to use the correct
         physical unit symbols. Max 12 letters.
     si : str
-        SI representation of the unit. Can be 
+        SI representation of the unit. Can be
         omitted.
-    
+
     Returns
     -------
     unit : metacatalog.Unit
@@ -123,15 +123,15 @@ def add_variable(session, name, symbol, unit):
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     name : str
         The variable name. Max 64 letters.
     symbol : str
-        The variable symbol. Try to use the correct 
+        The variable symbol. Try to use the correct
         physical variable symbols and avoid dublicates.
     unit : int, str
-        Either the id or **full** name of the unit to be 
+        Either the id or **full** name of the unit to be
         linked to this variable.
 
     Returns
@@ -165,34 +165,34 @@ def add_keyword(session, path, thesaurus):
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     path : str
         A full path to the keyword, each element connected
-        by a ' > ' sequence. E.g.: 
+        by a ' > ' sequence. E.g.:
         Topic > Term > Variable_level_1 etc.
     thesaurus : dict, int
         .. versionadded:: 0.1.10
-        Either a thesaurus entity, that distributes the 
-        controlled keywords, or an id of the an already 
+        Either a thesaurus entity, that distributes the
+        controlled keywords, or an id of the an already
         existing thesaurusName. It is highly recommended
         to use an existing ID.
 
     Note
     ----
-    This API endpoint is designed to add custom keywords to 
-    metacatalog. It will use the full path keywords and split 
-    them automatically for convenience. 
+    This API endpoint is designed to add custom keywords to
+    metacatalog. It will use the full path keywords and split
+    them automatically for convenience.
     .. warning::
-        Each keyword part will receive a **new** UUID, thus you 
-        have to use the `metacatalog.models.Keyword` interface 
-        to add **existing** keywords, that already contain a 
+        Each keyword part will receive a **new** UUID, thus you
+        have to use the `metacatalog.models.Keyword` interface
+        to add **existing** keywords, that already contain a
         UUID.
 
     Returns
     -------
     keywords, list of metacatalog.Keywords
-        List of the deconstructed Keyword entities    
+        List of the deconstructed Keyword entities
 
     """
     levels = path.upper().split(' > ')
@@ -214,8 +214,8 @@ def add_keyword(session, path, thesaurus):
             current = add_record(session=session, tablename='keywords', **attr)
         keywords.append(current)
         current_parent_id = current.id
-    
-    # return 
+
+    # return
     return keywords
 
 
@@ -226,38 +226,38 @@ def add_thesaurus(session, name, title, organisation, url, description=None, uui
     Add a new thesaurus to reference new keywords.
 
     .. warning::
-        If you want to add existing Thesaurii for reference, 
+        If you want to add existing Thesaurii for reference,
         you **have to** to add their existing UUID as well,
         otherwise this function will assign new ones.
 
     Attributes
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     uuid : str
         An UUID version 4 to globally identify the keyword list.
-        If you add a new thesaurus, do not set the UUID as a new 
-        UUID will be set. 
+        If you add a new thesaurus, do not set the UUID as a new
+        UUID will be set.
     name : str
-        Short name of the keyword list. Do not use the full 
-        qualified name here, just the short version used for 
+        Short name of the keyword list. Do not use the full
+        qualified name here, just the short version used for
         filtering.
     title : str
-        Full qualified name used by the distributor to identify 
+        Full qualified name used by the distributor to identify
         the keyword list globally.
     organisation : str
-        The full organisation name to identify the authority 
+        The full organisation name to identify the authority
         maintaining the thesaurus.
     description : str
-        Optional. Futher details about the thesaurus, like scope or 
+        Optional. Futher details about the thesaurus, like scope or
         implementation details.
     url : str
-        The permanent URL at which the full keyword list can be 
+        The permanent URL at which the full keyword list can be
         found. **Do not link the organisation or an overview page here**.
-        Usually, this points to an XML representation of the 
-        thesaurus. It may contain a placeholder called UUID to 
+        Usually, this points to an XML representation of the
+        thesaurus. It may contain a placeholder called UUID to
         load specific keyword objects only.
-    
+
     Returns
     -------
     thesaurus : metacatalog.models.Thesaurus
@@ -266,7 +266,7 @@ def add_thesaurus(session, name, title, organisation, url, description=None, uui
     """
     if uuid is None:
         uuid = uuid4()
-    
+
     attr = dict(
         uuid=uuid,
         name=name,
@@ -275,43 +275,48 @@ def add_thesaurus(session, name, title, organisation, url, description=None, uui
         description=description,
         url=url
     )
-    
+
     return add_record(session, tablename='thesaurus', **attr)
 
 
-def add_person(session, first_name, last_name, organisation_name=None, organisation_abbrev=None, affiliation=None, attribution=None):
+def add_person(session, first_name, last_name, organisation_name=None, organisation_abbrev=None, affiliation=None, attribution=None, uuid=None):
     r"""Add new Person
 
     Add a new Person to the database. A person can be a real Person
-    or an institution. Then, the institution name goes into the 
+    or an institution. Then, the institution name goes into the
     last_name column and first_name can actively be set to None.
     An affiliation can be added to both as a single string.
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
+    uuid : str
+        .. versionadded: 0.2.7
+        An UUID version 4 to globally identify the person list.
+        If you add a new person, do not set the UUID as a new
+        UUID will be set.
     first_name : str
-        A real persons first name. If omitted, the 'Person' is 
+        A real persons first name. If omitted, the 'Person' is
         assumed to be an institution
     last_name : str
-        A real persions last name. If first_name is NULL, 
-        last_name is assumned to be an institution.
+        A real persons last name. If first_name is NULL,
+        last_name is assumed to be an institution.
     organisation_name : str
         .. versionadded:: 0.1.10
         Optional, but **highly_recommended** if applicable. Name of
         the head institution, whithout department.
     organisation_abbrev : str
         .. versionadded:: 0.2.6
-        Optional, abbreviated version of the Institution. I.e. the 
+        Optional, abbreviated version of the Institution. I.e. the
         famous Karlsruhe Institute of Technology is better known as 'KIT'
     affiliation : str
         Affiliation if applicable. Has to go into a single string
         of 1024 bytes. Full attribution including department and group name.
     attribution : str.
-        Optional. Attribution recommondation for all datasets 
+        Optional. Attribution recommondation for all datasets
         this Person is associated to as a first author.
-    
+
     Returns
     -------
     entry: metacatalog.Person
@@ -320,13 +325,17 @@ def add_person(session, first_name, last_name, organisation_name=None, organisat
     See Also
     --------
     add_organisation
-  
+
     """
+    if uuid is None:
+        uuid = uuid4()
+
     attr = dict(
+        uuid=uuid,
         is_organisation=False,
-        first_name=first_name, 
+        first_name=first_name,
         last_name=last_name,
-        organisation_name=organisation_name, 
+        organisation_name=organisation_name,
         organisation_abbrev=organisation_abbrev,
         affiliation=affiliation,
         attribution=attribution
@@ -339,25 +348,25 @@ def add_organisation(session, organisation_name, organisation_abbrev=None, affil
     r"""Add new Organisation
     .. versionadded:: 0.2.6
 
-    Add a new Organisation to the database. This is internally handled as a 
+    Add a new Organisation to the database. This is internally handled as a
     Person, but with ``is_organisation==True``.
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     organisation_name : str
         Required. Name of the head institution, whithout department.
     organisation_abbrev : str
-        Optional, abbreviated version of the Institution. I.e. the 
+        Optional, abbreviated version of the Institution. I.e. the
         famous Karlsruhe Institute of Technology is better known as 'KIT'
     affiliation : str
         Affiliation if applicable. Has to go into a single string
         of 1024 bytes. Full attribution including department and group name.
     attribution : str.
-        Optional. Attribution recommondation for all datasets 
+        Optional. Attribution recommondation for all datasets
         this Person is associated to as a first author.
-    
+
     Returns
     -------
     entry: metacatalog.Person
@@ -366,7 +375,7 @@ def add_organisation(session, organisation_name, organisation_abbrev=None, affil
     See Also
     --------
     add_person
-  
+
     """
     attr = dict(
         is_organisation=True,
@@ -384,7 +393,7 @@ def add_organisation(session, organisation_name, organisation_abbrev=None, affil
 def add_group(session, group_type, entry_ids, title=None, description=None):
     """
     .. versionadded:: 0.2
-    Adds a new EntryGroup to the database. The Entry(s) have to exist in the 
+    Adds a new EntryGroup to the database. The Entry(s) have to exist in the
     database to be associated correctly.
 
     Parameters
@@ -392,10 +401,10 @@ def add_group(session, group_type, entry_ids, title=None, description=None):
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     group_type : int, str
-        Either :class:`EntryGroupType <metacatalog.models.EntryGroupType>` 
+        Either :class:`EntryGroupType <metacatalog.models.EntryGroupType>`
         id or name to be used.
     entry_ids : list of int
-        List of :class:`Entry.id <metacatalog.models.Entry>` to be associated 
+        List of :class:`Entry.id <metacatalog.models.Entry>` to be associated
         tp this Group.
     title : str
         Optional title of this Group. Mandatory, if the type is a 'Project'
@@ -407,7 +416,7 @@ def add_group(session, group_type, entry_ids, title=None, description=None):
     -------
     entry: metacatalog.models.EntryGroup
         EntryGroup instance of the added group
-    
+
     """
     # check ids
     if isinstance(entry_ids, int):
@@ -427,7 +436,7 @@ def add_group(session, group_type, entry_ids, title=None, description=None):
 
     if type_.name == 'Project' and (title is None or description is None):
         raise AttributeError("Projects must not omit title and description.")
-    
+
     # load entries
     entries = [api.find_entry(session, id=id_)[0] for id_ in entry_ids]
 
@@ -444,7 +453,7 @@ def add_group(session, group_type, entry_ids, title=None, description=None):
 def add_project(session, entry_ids, title=None, description=None):
     """
     .. versionadded:: 0.2
-    Adds a new Project EntryGroup to the database. 
+    Adds a new Project EntryGroup to the database.
     The Entry(s) have to exist in the database to be associated correctly.
 
     Parameters
@@ -452,7 +461,7 @@ def add_project(session, entry_ids, title=None, description=None):
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     entry_ids : list of int
-        List of :class:`Entry.id <metacatalog.models.Entry>` to be associated 
+        List of :class:`Entry.id <metacatalog.models.Entry>` to be associated
         tp this Project.
     title : str
         Project title.
@@ -463,7 +472,7 @@ def add_project(session, entry_ids, title=None, description=None):
     -------
     entry: metacatalog.models.EntryGroup
         EntryGroup instance of the added group
-    
+
     """
     type_ = api.find_group_type(session, name='Project')[0]
     return add_group(session=session, group_type=type_, entry_ids=entry_ids, title=title, description=description)
@@ -474,34 +483,34 @@ def add_entry(session, title, author, location, variable, abstract=None, externa
     r"""Add new Entry
 
     Adds a new metadata Entry to the database. This method will create the core
-    entry. Usually, more steps are necessary, which will need the newly created 
-    database ID. Such steps are: 
-    
+    entry. Usually, more steps are necessary, which will need the newly created
+    database ID. Such steps are:
+
     * adding contributors   (mandatory)
     * adding data           (extremly useful)
     * adding keywords       (recommended)
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     title : str
         Title of the Entry
     author : int, str
-        First author of the Entry. The Person record has to exist already in the 
+        First author of the Entry. The Person record has to exist already in the
         database and can be found by exact match on id (int) or last_name (str).
     location : str, tuple
-        Can be either a WKT of a EPSG:4326 location, or the coordinates as a 
+        Can be either a WKT of a EPSG:4326 location, or the coordinates as a
         tuple. It has to be (X,Y), to (longitude, latitude)
     variable : int, str
-        **Full** variable name (str) or ID (int) of the data described by the Entry. 
+        **Full** variable name (str) or ID (int) of the data described by the Entry.
     abstract : str
         Description of the data. Be as detailed as possible
     external_id : str
-        If the data described by Entry has another unique identifier, 
+        If the data described by Entry has another unique identifier,
         usually supplied by the data provider, it can be stored for reference reasons.
     comment : str
-        General purpose comment that should not contain any vital information to 
+        General purpose comment that should not contain any vital information to
         understand the entry. If it's vital, it should go into the abstract.
     geom : str
         WKT of any additional geoinformation in EPSG:4326
@@ -520,8 +529,8 @@ def add_entry(session, title, author, location, variable, abstract=None, externa
     """
     # create the attribute dict
     attr = dict(
-        title=title, 
-        abstract=abstract, 
+        title=title,
+        abstract=abstract,
         external_id=external_id,
         embargo=embargo
     )
@@ -543,7 +552,7 @@ def add_entry(session, title, author, location, variable, abstract=None, externa
 
     if geom is not None and isinstance(geom, str):
         attr['geom'] = geom
-    
+
     # handle variable
     if isinstance(variable, int):
         variable = api.find_variable(session=session, id=variable, return_iterator=True).one()
@@ -578,12 +587,12 @@ def add_details_to_entries(session, entries, details=None, **kwargs):
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     entries : list
-        List of identifier or single identifier to load entries. 
+        List of identifier or single identifier to load entries.
         If int, the Entry.id is assumed. If str, title is assumed.
-        Can also pass a metacatalog.Entry object. 
+        Can also pass a metacatalog.Entry object.
     details : list, None
         .. versionadded:: 0.1.8
         List of dict of structure:
@@ -593,12 +602,12 @@ def add_details_to_entries(session, entries, details=None, **kwargs):
                 'value': '',
                 'description': ''
             }]
-        where the ``description`` is optional and can be omitted. 
+        where the ``description`` is optional and can be omitted.
         If no descriptions are passed at all, you can also use `**kwargs`
         to pass ``key=value`` pairs. You can mix `details` and `kwargs`
     kwargs : keyword arguments
-        Each keyword argument will be added as a 
-        py:class:`metacatalog.models.Detail` and linked to 
+        Each keyword argument will be added as a
+        py:class:`metacatalog.models.Detail` and linked to
         each entry
 
     """
@@ -628,36 +637,36 @@ def add_keywords_to_entries(session, entries, keywords, alias=None, values=None)
     r"""Associate keyword(s) to entrie(s)
 
     Adds associations between entries and keywords. The Entry and Keyword
-    instances have to already exist in the database. Keywords are usually 
-    prepopulated. You might want to alias an keyword or associate a value to 
+    instances have to already exist in the database. Keywords are usually
+    prepopulated. You might want to alias an keyword or associate a value to
     it. Use the alias and value lists for this.
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     entries : list
-        List of identifier or single identifier to load entries. 
+        List of identifier or single identifier to load entries.
         If int, the Entry.id is assumed. If str, title is assumed.
-        Can also pass a metacatalog.Entry object. 
+        Can also pass a metacatalog.Entry object.
     keywords : list
         List of identifier or single identifier to load keywords.
         If int, Keyword.id is assumed, If str, Keyword.value is assumed.
         Can also pass a metacatalog.Keyword object.
     alias : list
-        List of, or single alias names. The shape has to match the 
-        keywords parameter. These alias will rename the keywords on 
-        association. In case one instance should not recive an alias, 
+        List of, or single alias names. The shape has to match the
+        keywords parameter. These alias will rename the keywords on
+        association. In case one instance should not recive an alias,
         pass None instead.
     values : list
-        List of, or single value. The shape has to match the 
+        List of, or single value. The shape has to match the
         keywords parameter. These values will be stored along with the
-        association to the entries. In case one instance should not 
+        association to the entries. In case one instance should not
         be associated to a value pass None instead.
 
         .. deprecated:: 0.1.6
-            `values` will be removed in 0.2. Rather use 
-            `metacatalog.models.Detail` to store custom key-values 
+            `values` will be removed in 0.2. Rather use
+            `metacatalog.models.Detail` to store custom key-values
 
 
     Returns
@@ -693,7 +702,7 @@ def add_keywords_to_entries(session, entries, keywords, alias=None, values=None)
             entry = api.find_entry(session=session, title=entry_id, return_iterator=True).first()
         else:
             raise AttributeError("Value '%s' not allowed for entries" % str(type(entry_id)))
-        
+
         # add each keyword
         assocs = []
         for keyword_id, alias_name, value in zip(keywords, alias, values):
@@ -706,10 +715,10 @@ def add_keywords_to_entries(session, entries, keywords, alias=None, values=None)
                 keyword = api.find_keyword(session=session, value=keyword_id, return_iterator=True).first()
             else:
                 raise AttributeError("Value '%s' not allowed for keywords" % str(type(keyword_id)))
-        
+
             # create a new keyword association
             assocs.append(models.KeywordAssociation(entry=entry, keyword=keyword, alias=alias_name, associated_value=value))
-        
+
         # add keyword to current entry
         try:
             entry.keywords.extend(assocs)
@@ -724,28 +733,28 @@ def add_persons_to_entries(session, entries, persons, roles, order):
     r"""Add person(s) to entrie(s)
 
     Adds associations between entries and persons. The Entry and Person
-    instances have to already exist in the database. Each association 
+    instances have to already exist in the database. Each association
     has to further define the role of the person for the respective entry.
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     entries : list
-        List of identifier or single identifier to load entries. 
+        List of identifier or single identifier to load entries.
         If int, the Entry.id is assumed. If str, title is assumed.
-        Can also pass a metacatalog.Entry object. 
+        Can also pass a metacatalog.Entry object.
     persons : list
         List of identifier or single identifier to load persons.
         If int, Person.id is assumed, If str, Person.last_name is assumed.
         Can also pass a metacatalog.Person object.
     roles : list
-        List of, or single role. The shape has to match the 
+        List of, or single role. The shape has to match the
         persons parameter. The role has to be identifies by id (int) or
         role name (str).
     order : list
-        List of, or single order. The shape has to match the 
-        persons parameter. The order gives the ascending order of 
+        List of, or single order. The shape has to match the
+        persons parameter. The order gives the ascending order of
         contributors on the respecive entry (after the author).
 
     Returns
@@ -757,7 +766,7 @@ def add_persons_to_entries(session, entries, persons, roles, order):
     metacatalog.Entry
     metacatalog.Person
     metacatalog.PersonRole
-    
+
     """
     # check the input shapes
     if not isinstance(entries, list):
